@@ -1,4 +1,4 @@
-#include "myproject.hpp"
+#include "my_cpp_project.hpp"
 
 #include <pybind11/pybind11.h>
 
@@ -9,10 +9,10 @@ namespace py = pybind11;
 
 PYBIND11_MODULE(_python_api, m) {
     m.doc() = R"pbdoc(
-        Python wrapper for `myproject`.
+        Python wrapper for `my_cpp_project`.
 
         This information will be displayed when using `help()`:
-        $ python -c "import myproject; help(myproject)"
+        $ python -c "import my_python_api; help(my_python_api)"
     )pbdoc";
 
     m.def("add", &add, "Add two numbers together");
